==> xwiki-platform-component-multi-9.0-sources.jar: org/xwiki/component/internal/DocumentComponentManagerFactory.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.component.internal;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.component.internal.multi.ComponentManagerFactory;
import org.xwiki.model.EntityType;

/**
 * Implementation of {@link ComponentManagerFactory} which force parent to be {@link SpaceComponentManager}.
 * 
 * @version $Id: 0c518c789472cc4daad8063213e87a17b8e523cb $
 * @since 5.0M2
 */
@Component
@Named(DocumentComponentManager.ID)
@Singleton
public class DocumentComponentManagerFactory extends AbstractEnityComponentManagerFactory
{
    @Override
    protected EntityType getEntityType()
    {
        return EntityType.DOCUMENT;
    }
}

==> xwiki-platform-component-multi-11.10.8-sources.jar: org/xwiki/component/internal/DocumentComponentManagerFactory.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.component.internal;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.component.internal.multi.ComponentManagerFactory;
import org.xwiki.model.EntityType;
import org.xwiki.model.namespace.DocumentNamespace;

/**
 * Implementation of {@link ComponentManagerFactory} which force parent to be {@link SpaceComponentManager}.
 * 
 * @version $Id: d3173654244e2e606283c9593bec398b7295d3a4 $
 * @since 5.0M2
 */
@Component
@Named(DocumentNamespace.TYPE)
@Singleton
public class DocumentComponentManagerFactory extends AbstractEnityComponentManagerFactory
{
    @Override
    protected EntityType getEntityType()
    {
        return EntityType.DOCUMENT;
    }
}
